==> senior_platform_authentication_ui-0.0.1.tar.gz: test/src/core/utils/validators_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:senior_platform_authentication_ui/src/core/l10n/.gen/app_localizations.dart';
import 'package:senior_platform_authentication_ui/src/core/l10n/l10n_extension.dart';
import 'package:senior_platform_authentication_ui/src/core/utils/validators.dart';

void main() {
  group('validateUserName', () {
    testWidgets('invalid UserName message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage = validateUserName(context, 'invalid_email');
              expect(errorMessage, context.l10n.username_invalid_message);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });

    testWidgets('required UserName message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage = validateUserName(context, '');
              expect(errorMessage, context.l10n.username_required_message);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });

    testWidgets('valid UserName message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage =
                  validateUserName(context, 'valid_email@senior.com.br');
              expect(errorMessage, null);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });
  });

  group('validatePassword', () {
    testWidgets('required Password message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage = validatePassword(context, '');
              expect(errorMessage, context.l10n.password_required_message);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });

    testWidgets('valid Password message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage = validatePassword(context, 'Tteste1!');
              expect(errorMessage, null);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });
  });
}

==> senior_platform_authentication_ui-4.0.0.tar.gz: test/src/core/utils/validators_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:senior_platform_authentication_ui/src/core/l10n/gen/app_localizations.dart';
import 'package:senior_platform_authentication_ui/src/core/l10n/l10n_extension.dart';
import 'package:senior_platform_authentication_ui/src/core/utils/validators.dart';

void main() {
  group('validateUserName', () {
    testWidgets('invalid UserName message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage = validateUserName(context, 'invalid_email');
              expect(errorMessage, context.l10n.usernameInvalidMessage);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });

    testWidgets('required UserName message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage = validateUserName(context, '');
              expect(errorMessage, context.l10n.usernameRequiredMessage);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });

    testWidgets('valid UserName message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage =
                  validateUserName(context, 'valid_email@senior.com.br');
              expect(errorMessage, null);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });
  });

  group('validatePassword', () {
    testWidgets('required Password message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage = validatePassword(context, '');
              expect(errorMessage, context.l10n.passwordRequiredMessage);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });

    testWidgets('valid Password message', (WidgetTester tester) async {
      await tester.pumpWidget(
        MaterialApp(
          localizationsDelegates: AppLocalizations.localizationsDelegates,
          supportedLocales: AppLocalizations.supportedLocales,
          home: Builder(
            builder: (BuildContext context) {
              final errorMessage = validatePassword(context, 'Tteste1!');
              expect(errorMessage, null);
              return const SizedBox.shrink();
            },
          ),
        ),
      );
    });
  });
}
